@@ -1,11 +1,12 @@
 import functools
+import operator
+import sys
+
 import hypothesis
 import hypothesis.stateful
 import hypothesis.strategies as st
-import operator
 import pytest
 import redis
-import sys
 from hypothesis.stateful import rule, initialize, precondition
 
 import fakeredis
@@ -77,9 +78,8 @@ class WrappedException:
             return NotImplemented
         if type(self.wrapped) != type(other.wrapped):  # noqa: E721
             return False
-        # TODO: re-enable after more carefully handling order of error checks
-        # return self.wrapped.args == other.wrapped.args
         return True
+        # return self.wrapped.args == other.wrapped.args
 
     def __ne__(self, other):
         if not isinstance(other, WrappedException):
@@ -254,7 +254,7 @@ class CommonMachine(hypothesis.stateful.RuleBasedStateMachine):
         if self.real.info('server').get('arch_bits') != 64:
             self.real.connection_pool.disconnect()
             pytest.skip('redis server is not 64-bit')
-        self.fake = fakeredis.FakeStrictRedis(version=redis_ver)
+        self.fake = fakeredis.FakeStrictRedis(server=fakeredis.FakeServer(version=redis_ver))
         # Disable the response parsing so that we can check the raw values returned
         self.fake.response_callbacks.clear()
         self.real.response_callbacks.clear()
@@ -403,10 +403,8 @@ class TestString(BaseTest):
 
 
 class TestHash(BaseTest):
-    # TODO: add a test for hincrbyfloat. See incrbyfloat for why this is
-    # problematic.
     hash_commands = (
-            commands(st.just('hmset'), keys, st.lists(st.tuples(fields, values)))
+            commands(st.just('hset'), keys, st.lists(st.tuples(fields, values)))
             | commands(st.just('hdel'), keys, st.lists(fields))
             | commands(st.just('hexists'), keys, fields)
             | commands(st.just('hget'), keys, fields)
@@ -414,12 +412,12 @@ class TestHash(BaseTest):
             | commands(st.just('hincrby'), keys, fields, st.integers())
             | commands(st.just('hlen'), keys)
             | commands(st.just('hmget'), keys, st.lists(fields))
-            | commands(st.sampled_from(['hset', 'hmset']), keys, st.lists(st.tuples(fields, values)))
+            | commands(st.just('hset'), keys, st.lists(st.tuples(fields, values)))
             | commands(st.just('hsetnx'), keys, fields, values)
             | commands(st.just('hstrlen'), keys, fields)
     )
     create_command_strategy = (
-        commands(st.just('hmset'), keys, st.lists(st.tuples(fields, values), min_size=1))
+        commands(st.just('hset'), keys, st.lists(st.tuples(fields, values), min_size=1))
     )
     command_strategy = hash_commands | common_commands
 
