@@ -5,11 +5,12 @@ Tests for `fakeredis-py`'s emulation of Redis's JSON.GET command subset.
 from __future__ import annotations
 
 import json
+
 import pytest
 import redis
 from redis.commands.json.path import Path
 
-from test.testtools import raw_command
+from test import testtools
 
 json_tests = pytest.importorskip("jsonpath_ng")
 
@@ -37,7 +38,7 @@ def test_jsonget(r: redis.Redis):
     assert r.json().get("foo", Path("$.a"), Path("$.x")) == {'$.a': [], '$.x': ['bar']}
 
 
-def test_json_setgetdeleteforget(r: redis.Redis) -> None:
+def test_json_setgetdeleteforget(r: redis.Redis):
     data = {'x': "bar"}
     assert r.json().set("foo", Path.root_path(), data) == 1
     assert r.json().get("foo") == data
@@ -47,7 +48,7 @@ def test_json_setgetdeleteforget(r: redis.Redis) -> None:
     assert r.exists("foo") == 0
 
 
-def test_json_delete_with_dollar(r: redis.Redis) -> None:
+def test_json_delete_with_dollar(r: redis.Redis):
     doc1 = {"a": 1, "nested": {"a": 2, "b": 3}}
     assert r.json().set("doc1", Path.root_path(), doc1)
     assert r.json().delete("doc1", "$..a") == 2
@@ -91,13 +92,13 @@ def test_json_et_non_dict_value(r: redis.Redis):
     assert r.json().get('str') == 'str_val'
 
     r.json().set("bool", Path.root_path(), True)
-    assert r.json().get('bool') == True
+    assert r.json().get('bool') is True
 
     r.json().set("bool", Path.root_path(), False)
-    assert r.json().get('bool') == False
+    assert r.json().get('bool') is False
 
 
-def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis) -> None:
+def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis):
     obj = {"foo": "bar"}
     assert r.json().set("obj", Path.root_path(), obj)
 
@@ -115,7 +116,7 @@ def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis) -> None:
 
     # Test with raw
     obj = {"foo": "bar"}
-    raw_command(r, 'json.set', 'obj', '$', json.dumps(obj))
+    testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps(obj))
     assert r.json().get('obj') == obj
 
 
@@ -123,12 +124,12 @@ def test_jsonset_flags_should_be_mutually_exclusive(r: redis.Redis):
     with pytest.raises(Exception):
         r.json().set("obj", Path("foo"), "baz", nx=True, xx=True)
     with pytest.raises(redis.ResponseError):
-        raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'NX', 'XX')
+        testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'NX', 'XX')
 
 
 def test_json_unknown_param(r: redis.Redis):
     with pytest.raises(redis.ResponseError):
-        raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'unknown')
+        testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'unknown')
 
 
 def test_jsonmget(r: redis.Redis):
@@ -153,7 +154,7 @@ def test_jsonmget(r: redis.Redis):
     assert r.json().mget(["missing_doc1", "missing_doc2"], "$..a") == [None, None]
 
 
-def test_jsonmget_should_succeed(r: redis.Redis) -> None:
+def test_jsonmget_should_succeed(r: redis.Redis):
     r.json().set("1", Path.root_path(), 1)
     r.json().set("2", Path.root_path(), 2)
 
@@ -162,14 +163,14 @@ def test_jsonmget_should_succeed(r: redis.Redis) -> None:
     assert r.json().mget([1, 2], Path.root_path()) == [1, 2]
 
 
-def test_jsonclear(r: redis.Redis) -> None:
+def test_jsonclear(r: redis.Redis):
     r.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4], )
 
     assert 1 == r.json().clear("arr", Path.root_path(), )
     assert [] == r.json().get("arr")
 
 
-def test_jsonclear_dollar(r: redis.Redis) -> None:
+def test_jsonclear_dollar(r: redis.Redis):
     data = {
         "nested1": {"a": {"foo": 10, "bar": 20}},
         "a": ["foo"],
@@ -201,7 +202,7 @@ def test_jsonclear_dollar(r: redis.Redis) -> None:
     assert r.json().get("doc1", "$") == [{}]
 
 
-def test_jsonclear_no_doc(r: redis.Redis) -> None:
+def test_jsonclear_no_doc(r: redis.Redis):
     # Test missing key
     with pytest.raises(redis.ResponseError):
         r.json().clear("non_existing_doc", "$..a")
@@ -240,7 +241,7 @@ def test_jsonstrlen(r: redis.Redis):
         r.json().strlen("non_existing_doc", "$..a")
 
 
-def test_toggle(r: redis.Redis) -> None:
+def test_toggle(r: redis.Redis):
     r.json().set("bool", Path.root_path(), False)
     assert r.json().toggle("bool", Path.root_path())
     assert r.json().toggle("bool", Path.root_path()) is False
@@ -251,7 +252,7 @@ def test_toggle(r: redis.Redis) -> None:
         r.json().toggle("num", Path.root_path())
 
 
-def test_toggle_dollar(r: redis.Redis) -> None:
+def test_toggle_dollar(r: redis.Redis):
     data = {
         "a": ["foo"],
         "nested1": {"a": False},
@@ -270,7 +271,7 @@ def test_toggle_dollar(r: redis.Redis) -> None:
         r.json().toggle("non_existing_doc", "$..a")
 
 
-def test_json_commands_in_pipeline(r: redis.Redis) -> None:
+def test_json_commands_in_pipeline(r: redis.Redis):
     p = r.json().pipeline()
     p.set("foo", Path.root_path(), "bar")
     p.get("foo")
@@ -296,7 +297,7 @@ def test_json_commands_in_pipeline(r: redis.Redis) -> None:
     assert r.get("foo") is None
 
 
-def test_strappend(r: redis.Redis) -> None:
+def test_strappend(r: redis.Redis):
     # Test single
     r.json().set("json-key", Path.root_path(), "foo")
     assert r.json().strappend("json-key", "bar") == 6
@@ -326,8 +327,8 @@ def test_strappend(r: redis.Redis) -> None:
         r.json().strappend("doc1", "add", "piu")
 
     # Test raw command with no arguments
-    with pytest.raises(redis.ResponseError) as e:
-        raw_command(r, 'json.strappend', '')
+    with pytest.raises(redis.ResponseError):
+        testtools.raw_command(r, 'json.strappend', '')
 
 
 @pytest.mark.decode_responses(True)
@@ -339,7 +340,7 @@ def test_decode_response_disabaled_null(r: redis.Redis):
     assert r.json().get("abc") is None
 
 
-def test_json_get_jset(r: redis.Redis) -> None:
+def test_json_get_jset(r: redis.Redis):
     assert r.json().set("foo", Path.root_path(), "bar", ) == 1
     assert "bar" == r.json().get("foo")
     assert r.json().get("baz") is None
@@ -347,14 +348,14 @@ def test_json_get_jset(r: redis.Redis) -> None:
     assert r.exists("foo") == 0
 
 
-def test_nonascii_setgetdelete(r: redis.Redis) -> None:
+def test_nonascii_setgetdelete(r: redis.Redis):
     assert r.json().set("not-ascii", Path.root_path(), "hyvää-élève", )
     assert "hyvää-élève" == r.json().get("not-ascii", no_escape=True, )
     assert 1 == r.json().delete("not-ascii")
     assert r.exists("not-ascii") == 0
 
 
-def test_json_setbinarykey(r: redis.Redis) -> None:
+def test_json_setbinarykey(r: redis.Redis):
     data = {"hello": "world", b"some": "value"}
 
     with pytest.raises(TypeError):
@@ -363,7 +364,7 @@ def test_json_setbinarykey(r: redis.Redis) -> None:
     assert r.json().set("some-key", Path.root_path(), data, decode_keys=True)
 
 
-def test_set_file(r: redis.Redis) -> None:
+def test_set_file(r: redis.Redis):
     # Standard Library Imports
     import json
     import tempfile
@@ -382,27 +383,24 @@ def test_set_file(r: redis.Redis) -> None:
         r.json().set_file("test2", Path.root_path(), no_json_file.name)
 
 
-def test_set_path(r: redis.Redis) -> None:
+def test_set_path(r: redis.Redis):
     # Standard Library Imports
     import json
     import tempfile
 
     root = tempfile.mkdtemp()
-    sub = tempfile.mkdtemp(dir=root)
-    jsonfile = tempfile.mktemp(suffix=".json", dir=sub)
-    no_json_file = tempfile.mktemp(dir=root)
+    jsonfile = tempfile.NamedTemporaryFile(mode="w+", dir=root, delete=False)
+    no_json_file = tempfile.NamedTemporaryFile(mode="a+", dir=root, delete=False)
+    jsonfile.write(json.dumps({"hello": "world"}))
+    jsonfile.close()
+    no_json_file.write("hello")
 
-    with open(jsonfile, "w+") as fp:
-        fp.write(json.dumps({"hello": "world"}))
-    with open(no_json_file, "a+") as fp:
-        fp.write("hello")
-
-    result = {jsonfile: True, no_json_file: False}
+    result = {jsonfile.name: True, no_json_file.name: False}
     assert r.json().set_path(Path.root_path(), root) == result
-    assert r.json().get(jsonfile.rsplit(".")[0]) == {"hello": "world"}
+    assert r.json().get(jsonfile.name.rsplit(".")[0]) == {"hello": "world"}
 
 
-def test_type(r: redis.Redis) -> None:
+def test_type(r: redis.Redis):
     r.json().set("1", Path.root_path(), 1, )
 
     assert r.json().type("1", Path.root_path(), ) == b"integer"
@@ -416,14 +414,14 @@ def test_type(r: redis.Redis) -> None:
     assert r.json().type("doc1", "$..a") == [k.encode() for k in meta_data.keys()]
 
     # Test single
-    assert r.json().type("doc1", f"$.integer.a") == [b'integer']
+    assert r.json().type("doc1", "$.integer.a") == [b'integer']
     assert r.json().type("doc1") == b'object'
 
     # Test missing key
     assert r.json().type("non_existing_doc", "..a") is None
 
 
-def test_objlen(r: redis.Redis) -> None:
+def test_objlen(r: redis.Redis):
     # Test missing key, and path
     with pytest.raises(redis.ResponseError):
         r.json().objlen("non_existing_doc", "$..a")
@@ -503,7 +501,7 @@ def test_objkeys(r: redis.Redis):
     assert r.json().objkeys("doc1", "$..nowhere") == []
 
 
-def test_numincrby(r: redis.Redis) -> None:
+def test_numincrby(r: redis.Redis):
     r.json().set("num", Path.root_path(), 1)
 
     assert 2 == r.json().numincrby("num", Path.root_path(), 1)
@@ -522,7 +520,7 @@ def test_numincrby(r: redis.Redis) -> None:
     assert r.json().numincrby("doc1", "$.b[1].a", 3.5) == [15.0]
 
 
-def test_nummultby(r: redis.Redis) -> None:
+def test_nummultby(r: redis.Redis):
     r.json().set("num", Path.root_path(), 1)
 
     with pytest.deprecated_call():
@@ -557,3 +555,29 @@ def test_nummultby(r: redis.Redis) -> None:
 
     with pytest.deprecated_call():
         assert r.json().nummultby("doc1", ".b[0].a", 3) == 6
+
+
+@testtools.run_test_if_redispy_ver('above', '5')
+def test_json_merge(r: redis.Redis):
+    # Test with root path $
+    key = "person_data"
+    r.json().set(key, Path.root_path(), {"person1": {"personal_data": {"name": "John"}}}, )
+    r.json().merge(key, Path.root_path(), {"person1": {"personal_data": {"hobbies": "reading"}}})
+    assert r.json().get(key) == {"person1": {"personal_data": {"name": "John", "hobbies": "reading"}}}
+
+    # Test with root path path $.person1.personal_data
+    r.json().merge(key, "$.person1.personal_data", {"country": "Israel"})
+    assert r.json().get(key) == {
+        "person1": {"personal_data": {"name": "John", "hobbies": "reading", "country": "Israel"}}}
+
+    # Test with null value to delete a value
+    r.json().merge("person_data", "$.person1.personal_data", {"name": None})
+    assert r.json().get(key) == {"person1": {"personal_data": {"country": "Israel", "hobbies": "reading"}}}
+
+
+@testtools.run_test_if_redispy_ver('above', '5')
+def test_mset(r: redis.Redis):
+    r.json().mset("1", Path.root_path(), 1, "2", Path.root_path(), 2)
+
+    assert r.json().mget(["1"], Path.root_path()) == [1]
+    assert r.json().mget(["1", "2"], Path.root_path()) == [1, 2]
