@@ -1,19 +1,16 @@
-import pytest
-import redis
 from datetime import datetime, timedelta
-from redis.exceptions import ResponseError
 from time import sleep, time
 
+import pytest
+import redis
+from redis.exceptions import ResponseError
+
+from fakeredis import _msgs as msgs
 from test.testtools import raw_command
 
 
-def key_val_dict(size=100):
-    return {b'key:' + bytes([i]): b'val:' + bytes([i])
-            for i in range(size)}
-
-
 @pytest.mark.slow
-def test_expireat_should_expire_key_by_datetime(r):
+def test_expireat_should_expire_key_by_datetime(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.expireat('foo', datetime.now() + timedelta(seconds=1))
@@ -23,7 +20,7 @@ def test_expireat_should_expire_key_by_datetime(r):
 
 
 @pytest.mark.slow
-def test_expireat_should_expire_key_by_timestamp(r):
+def test_expireat_should_expire_key_by_timestamp(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.expireat('foo', int(time() + 1))
@@ -32,22 +29,22 @@ def test_expireat_should_expire_key_by_timestamp(r):
     assert r.expire('bar', 1) is False
 
 
-def test_expireat_should_return_true_for_existing_key(r):
+def test_expireat_should_return_true_for_existing_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.expireat('foo', int(time() + 1)) is True
 
 
-def test_expireat_should_return_false_for_missing_key(r):
+def test_expireat_should_return_false_for_missing_key(r: redis.Redis):
     assert r.expireat('missing', int(time() + 1)) is False
 
 
-def test_del_operator(r):
+def test_del_operator(r: redis.Redis):
     r['foo'] = 'bar'
     del r['foo']
     assert r.get('foo') is None
 
 
-def test_expire_should_not_handle_floating_point_values(r):
+def test_expire_should_not_handle_floating_point_values(r: redis.Redis):
     r.set('foo', 'bar')
     with pytest.raises(redis.ResponseError, match='value is not an integer or out of range'):
         r.expire('something_new', 1.2)
@@ -56,47 +53,13 @@ def test_expire_should_not_handle_floating_point_values(r):
         r.pexpire('some_unused_key', 1000.2)
 
 
-def test_ttl_should_return_minus_one_for_non_expiring_key(r):
+def test_ttl_should_return_minus_one_for_non_expiring_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.ttl('foo') == -1
 
 
-def test_scan(r):
-    # Set up the data
-    for ix in range(20):
-        k = 'scan-test:%s' % ix
-        v = 'result:%s' % ix
-        r.set(k, v)
-    expected = r.keys()
-    assert len(expected) == 20  # Ensure we know what we're testing
-
-    # Test that we page through the results and get everything out
-    results = []
-    cursor = '0'
-    while cursor != 0:
-        cursor, data = r.scan(cursor, count=6)
-        results.extend(data)
-    assert set(expected) == set(results)
-
-    # Now test that the MATCH functionality works
-    results = []
-    cursor = '0'
-    while cursor != 0:
-        cursor, data = r.scan(cursor, match='*7', count=100)
-        results.extend(data)
-    assert b'scan-test:7' in results
-    assert b'scan-test:17' in results
-    assert len(results) == 2
-
-    # Test the match on iterator
-    results = [r for r in r.scan_iter(match='*7')]
-    assert b'scan-test:7' in results
-    assert b'scan-test:17' in results
-    assert len(results) == 2
-
-
-def test_sort_range_offset_range(r):
+def test_sort_range_offset_range(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '4')
@@ -105,7 +68,7 @@ def test_sort_range_offset_range(r):
     assert r.sort('foo', start=0, num=2) == [b'1', b'2']
 
 
-def test_sort_range_offset_range_and_desc(r):
+def test_sort_range_offset_range_and_desc(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '4')
@@ -114,12 +77,12 @@ def test_sort_range_offset_range_and_desc(r):
     assert r.sort("foo", start=0, num=1, desc=True) == [b"4"]
 
 
-def test_sort_range_offset_norange(r):
+def test_sort_range_offset_norange(r: redis.Redis):
     with pytest.raises(redis.RedisError):
         r.sort('foo', start=1)
 
 
-def test_sort_range_with_large_range(r):
+def test_sort_range_with_large_range(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '4')
@@ -128,14 +91,14 @@ def test_sort_range_with_large_range(r):
     assert r.sort('foo', start=1, num=20) == [b'2', b'3', b'4']
 
 
-def test_sort_descending(r):
+def test_sort_descending(r: redis.Redis):
     r.rpush('foo', '1')
     r.rpush('foo', '2')
     r.rpush('foo', '3')
     assert r.sort('foo', desc=True) == [b'3', b'2', b'1']
 
 
-def test_sort_alpha(r):
+def test_sort_alpha(r: redis.Redis):
     r.rpush('foo', '2a')
     r.rpush('foo', '1b')
     r.rpush('foo', '2b')
@@ -144,7 +107,7 @@ def test_sort_alpha(r):
     assert r.sort('foo', alpha=True) == [b'1a', b'1b', b'2a', b'2b']
 
 
-def test_sort_foo(r):
+def test_sort_foo(r: redis.Redis):
     r.rpush('foo', '2a')
     r.rpush('foo', '1b')
     r.rpush('foo', '2b')
@@ -153,17 +116,17 @@ def test_sort_foo(r):
         r.sort('foo', alpha=False)
 
 
-def test_sort_empty(r):
+def test_sort_empty(r: redis.Redis):
     assert r.sort('foo') == []
 
 
-def test_sort_wrong_type(r):
+def test_sort_wrong_type(r: redis.Redis):
     r.set('string', '3')
     with pytest.raises(redis.ResponseError):
         r.sort('string')
 
 
-def test_sort_with_store_option(r):
+def test_sort_with_store_option(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '4')
@@ -173,7 +136,7 @@ def test_sort_with_store_option(r):
     assert r.lrange('bar', 0, -1) == [b'1', b'2', b'3', b'4']
 
 
-def test_sort_with_by_and_get_option(r):
+def test_sort_with_by_and_get_option(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '4')
@@ -206,7 +169,7 @@ def test_sort_with_by_and_get_option(r):
     )
 
 
-def test_sort_with_hash(r):
+def test_sort_with_hash(r: redis.Redis):
     r.rpush('foo', 'middle')
     r.rpush('foo', 'eldest')
     r.rpush('foo', 'youngest')
@@ -226,19 +189,19 @@ def test_sort_with_hash(r):
     )
 
 
-def test_sort_with_set(r):
+def test_sort_with_set(r: redis.Redis):
     r.sadd('foo', '3')
     r.sadd('foo', '1')
     r.sadd('foo', '2')
     assert r.sort('foo') == [b'1', b'2', b'3']
 
 
-def test_ttl_should_return_minus_two_for_non_existent_key(r):
+def test_ttl_should_return_minus_two_for_non_existent_key(r: redis.Redis):
     assert r.get('foo') is None
     assert r.ttl('foo') == -2
 
 
-def test_type(r):
+def test_type(r: redis.Redis):
     r.set('string_key', "value")
     r.lpush("list_key", "value")
     r.sadd("set_key", "value")
@@ -253,17 +216,17 @@ def test_type(r):
     assert r.type('none_key') == b'none'
 
 
-def test_unlink(r):
+def test_unlink(r: redis.Redis):
     r.set('foo', 'bar')
     r.unlink('foo')
     assert r.get('foo') is None
 
 
-def test_dump_missing(r):
+def test_dump_missing(r: redis.Redis):
     assert r.dump('foo') is None
 
 
-def test_dump_restore(r):
+def test_dump_restore(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     r.restore('baz', 0, dump)
@@ -271,7 +234,7 @@ def test_dump_restore(r):
     assert r.ttl('baz') == -1
 
 
-def test_dump_restore_ttl(r):
+def test_dump_restore_ttl(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     r.restore('baz', 2000, dump)
@@ -279,7 +242,7 @@ def test_dump_restore_ttl(r):
     assert 1000 <= r.pttl('baz') <= 2000
 
 
-def test_dump_restore_replace(r):
+def test_dump_restore_replace(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     r.set('foo', 'baz')
@@ -287,40 +250,42 @@ def test_dump_restore_replace(r):
     assert r.get('foo') == b'bar'
 
 
-def test_restore_exists(r):
+def test_restore_exists(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     with pytest.raises(redis.exceptions.ResponseError):
         r.restore('foo', 0, dump)
 
 
-def test_restore_invalid_dump(r):
+def test_restore_invalid_dump(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     with pytest.raises(redis.exceptions.ResponseError):
         r.restore('baz', 0, dump[:-1])
 
 
-def test_restore_invalid_ttl(r):
+def test_restore_invalid_ttl(r: redis.Redis):
     r.set('foo', 'bar')
     dump = r.dump('foo')
     with pytest.raises(redis.exceptions.ResponseError):
         r.restore('baz', -1, dump)
 
 
-def test_set_then_get(r):
+def test_set_then_get(r: redis.Redis):
     assert r.set('foo', 'bar') is True
     assert r.get('foo') == b'bar'
 
 
-def test_exists(r):
+def test_exists(r: redis.Redis):
     assert 'foo' not in r
     r.set('foo', 'bar')
     assert 'foo' in r
+    with pytest.raises(redis.ResponseError, match=msgs.WRONG_ARGS_MSG6.format('exists')[4:]):
+        raw_command(r, 'exists')
 
 
 @pytest.mark.slow
-def test_expire_should_expire_key(r):
+def test_expire_should_expire_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.expire('foo', 1)
@@ -329,7 +294,7 @@ def test_expire_should_expire_key(r):
     assert r.expire('bar', 1) is False
 
 
-def test_expire_should_throw_error(r):
+def test_expire_should_throw_error(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     with pytest.raises(ResponseError):
@@ -343,22 +308,22 @@ def test_expire_should_throw_error(r):
 
 
 @pytest.mark.max_server('7')
-def test_expire_extra_params_return_error(r):
+def test_expire_extra_params_return_error(r: redis.Redis):
     with pytest.raises(redis.exceptions.ResponseError):
         r.expire('foo', 1, nx=True)
 
 
-def test_expire_should_return_true_for_existing_key(r):
+def test_expire_should_return_true_for_existing_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.expire('foo', 1) is True
 
 
-def test_expire_should_return_false_for_missing_key(r):
+def test_expire_should_return_false_for_missing_key(r: redis.Redis):
     assert r.expire('missing', 1) is False
 
 
 @pytest.mark.slow
-def test_expire_should_expire_key_using_timedelta(r):
+def test_expire_should_expire_key_using_timedelta(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.expire('foo', timedelta(seconds=1))
@@ -368,7 +333,7 @@ def test_expire_should_expire_key_using_timedelta(r):
 
 
 @pytest.mark.slow
-def test_expire_should_expire_immediately_with_millisecond_timedelta(r):
+def test_expire_should_expire_immediately_with_millisecond_timedelta(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.expire('foo', timedelta(milliseconds=750))
@@ -376,7 +341,7 @@ def test_expire_should_expire_immediately_with_millisecond_timedelta(r):
     assert r.expire('bar', 1) is False
 
 
-def test_watch_expire(r):
+def test_watch_expire(r: redis.Redis):
     """EXPIRE should mark a key as changed for WATCH."""
     r.set('foo', 'bar')
     with r.pipeline() as p:
@@ -389,7 +354,7 @@ def test_watch_expire(r):
 
 
 @pytest.mark.slow
-def test_pexpire_should_expire_key(r):
+def test_pexpire_should_expire_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.pexpire('foo', 150)
@@ -398,17 +363,17 @@ def test_pexpire_should_expire_key(r):
     assert r.pexpire('bar', 1) == 0
 
 
-def test_pexpire_should_return_truthy_for_existing_key(r):
+def test_pexpire_should_return_truthy_for_existing_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.pexpire('foo', 1)
 
 
-def test_pexpire_should_return_falsey_for_missing_key(r):
+def test_pexpire_should_return_falsey_for_missing_key(r: redis.Redis):
     assert not r.pexpire('missing', 1)
 
 
 @pytest.mark.slow
-def test_pexpire_should_expire_key_using_timedelta(r):
+def test_pexpire_should_expire_key_using_timedelta(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.pexpire('foo', timedelta(milliseconds=750))
@@ -420,7 +385,7 @@ def test_pexpire_should_expire_key_using_timedelta(r):
 
 
 @pytest.mark.slow
-def test_pexpireat_should_expire_key_by_datetime(r):
+def test_pexpireat_should_expire_key_by_datetime(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.pexpireat('foo', datetime.now() + timedelta(milliseconds=150))
@@ -430,7 +395,7 @@ def test_pexpireat_should_expire_key_by_datetime(r):
 
 
 @pytest.mark.slow
-def test_pexpireat_should_expire_key_by_timestamp(r):
+def test_pexpireat_should_expire_key_by_timestamp(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     r.pexpireat('foo', int(time() * 1000 + 150))
@@ -439,45 +404,45 @@ def test_pexpireat_should_expire_key_by_timestamp(r):
     assert r.expire('bar', 1) is False
 
 
-def test_pexpireat_should_return_true_for_existing_key(r):
+def test_pexpireat_should_return_true_for_existing_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.pexpireat('foo', int(time() * 1000 + 150))
 
 
-def test_pexpireat_should_return_false_for_missing_key(r):
+def test_pexpireat_should_return_false_for_missing_key(r: redis.Redis):
     assert not r.pexpireat('missing', int(time() * 1000 + 150))
 
 
-def test_pttl_should_return_minus_one_for_non_expiring_key(r):
+def test_pttl_should_return_minus_one_for_non_expiring_key(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.pttl('foo') == -1
 
 
-def test_pttl_should_return_minus_two_for_non_existent_key(r):
+def test_pttl_should_return_minus_two_for_non_existent_key(r: redis.Redis):
     assert r.get('foo') is None
     assert r.pttl('foo') == -2
 
 
-def test_randomkey_returns_none_on_empty_db(r):
+def test_randomkey_returns_none_on_empty_db(r: redis.Redis):
     assert r.randomkey() is None
 
 
-def test_randomkey_returns_existing_key(r):
+def test_randomkey_returns_existing_key(r: redis.Redis):
     r.set("foo", 1)
     r.set("bar", 2)
     r.set("baz", 3)
     assert r.randomkey().decode() in ("foo", "bar", "baz")
 
 
-def test_persist(r):
+def test_persist(r: redis.Redis):
     r.set('foo', 'bar', ex=20)
     assert r.persist('foo') == 1
     assert r.ttl('foo') == -1
     assert r.persist('foo') == 0
 
 
-def test_watch_persist(r):
+def test_watch_persist(r: redis.Redis):
     """PERSIST should mark a variable as changed."""
     r.set('foo', 'bar', ex=10000)
     with r.pipeline() as p:
@@ -489,46 +454,46 @@ def test_watch_persist(r):
             p.execute()
 
 
-def test_set_existing_key_persists(r):
+def test_set_existing_key_persists(r: redis.Redis):
     r.set('foo', 'bar', ex=20)
     r.set('foo', 'foo')
     assert r.ttl('foo') == -1
 
 
-def test_set_non_str_keys(r):
+def test_set_non_str_keys(r: redis.Redis):
     assert r.set(2, 'bar') is True
     assert r.get(2) == b'bar'
     assert r.get('2') == b'bar'
 
 
-def test_getset_not_exist(r):
+def test_getset_not_exist(r: redis.Redis):
     val = r.getset('foo', 'bar')
     assert val is None
     assert r.get('foo') == b'bar'
 
 
-def test_get_float_type(r):  # Test for issue #58
+def test_get_float_type(r: redis.Redis):  # Test for issue #58
     r.set('key', 123)
     assert r.get('key') == b'123'
     r.incr('key')
     assert r.get('key') == b'124'
 
 
-def test_set_float_value(r):
+def test_set_float_value(r: redis.Redis):
     x = 1.23456789123456789
     r.set('foo', x)
     assert float(r.get('foo')) == x
 
 
 @pytest.mark.min_server('7')
-def test_expire_should_not_expire__when_no_expire_is_set(r):
+def test_expire_should_not_expire__when_no_expire_is_set(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.expire('foo', 1, xx=True) == 0
 
 
 @pytest.mark.min_server('7')
-def test_expire_should_not_expire__when_expire_is_set(r):
+def test_expire_should_not_expire__when_expire_is_set(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.expire('foo', 1, nx=True) == 1
@@ -536,7 +501,7 @@ def test_expire_should_not_expire__when_expire_is_set(r):
 
 
 @pytest.mark.min_server('7')
-def test_expire_should_expire__when_expire_is_greater(r):
+def test_expire_should_expire__when_expire_is_greater(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.expire('foo', 100) == 1
@@ -545,33 +510,33 @@ def test_expire_should_expire__when_expire_is_greater(r):
 
 
 @pytest.mark.min_server('7')
-def test_expire_should_expire__when_expire_is_lessthan(r):
+def test_expire_should_expire__when_expire_is_lessthan(r: redis.Redis):
     r.set('foo', 'bar')
     assert r.get('foo') == b'bar'
     assert r.expire('foo', 20) == 1
     assert r.expire('foo', 10, lt=True) == 1
 
 
-def test_rename(r):
+def test_rename(r: redis.Redis):
     r.set('foo', 'unique value')
     assert r.rename('foo', 'bar')
     assert r.get('foo') is None
     assert r.get('bar') == b'unique value'
 
 
-def test_rename_nonexistent_key(r):
+def test_rename_nonexistent_key(r: redis.Redis):
     with pytest.raises(redis.ResponseError):
         r.rename('foo', 'bar')
 
 
-def test_renamenx_doesnt_exist(r):
+def test_renamenx_doesnt_exist(r: redis.Redis):
     r.set('foo', 'unique value')
     assert r.renamenx('foo', 'bar')
     assert r.get('foo') is None
     assert r.get('bar') == b'unique value'
 
 
-def test_rename_does_exist(r):
+def test_rename_does_exist(r: redis.Redis):
     r.set('foo', 'unique value')
     r.set('bar', 'unique value2')
     assert not r.renamenx('foo', 'bar')
@@ -579,14 +544,14 @@ def test_rename_does_exist(r):
     assert r.get('bar') == b'unique value2'
 
 
-def test_rename_expiry(r):
+def test_rename_expiry(r: redis.Redis):
     r.set('foo', 'value1', ex=10)
     r.set('bar', 'value2')
     r.rename('foo', 'bar')
     assert r.ttl('bar') > 0
 
 
-def test_keys(r):
+def test_keys(r: redis.Redis):
     r.set('', 'empty')
     r.set('abc\n', '')
     r.set('abc\\', '')
@@ -623,20 +588,20 @@ def test_keys(r):
     assert r.keys(r'abc[c-\e]e') == []
 
 
-def test_contains(r):
+def test_contains(r: redis.Redis):
     assert not r.exists('foo')
     r.set('foo', 'bar')
     assert r.exists('foo')
 
 
-def test_delete(r):
+def test_delete(r: redis.Redis):
     r['foo'] = 'bar'
     assert r.delete('foo') == 1
     assert r.get('foo') is None
 
 
 @pytest.mark.slow
-def test_delete_expire(r):
+def test_delete_expire(r: redis.Redis):
     r.set("foo", "bar", ex=1)
     r.delete("foo")
     r.set("foo", "bar")
@@ -644,7 +609,7 @@ def test_delete_expire(r):
     assert r.get("foo") == b'bar'
 
 
-def test_delete_multiple(r):
+def test_delete_multiple(r: redis.Redis):
     r['one'] = 'one'
     r['two'] = 'two'
     r['three'] = 'three'
@@ -659,64 +624,11 @@ def test_delete_multiple(r):
     assert r.get('three') is None
 
 
-def test_delete_nonexistent_key(r):
+def test_delete_nonexistent_key(r: redis.Redis):
     assert r.delete('foo') == 0
 
 
-def test_scan_single(r):
-    r.set('foo1', 'bar1')
-    assert r.scan(match="foo*") == (0, [b'foo1'])
-
-
-def test_scan_iter_single_page(r):
-    r.set('foo1', 'bar1')
-    r.set('foo2', 'bar2')
-    assert set(r.scan_iter(match="foo*")) == {b'foo1', b'foo2'}
-    assert set(r.scan_iter()) == {b'foo1', b'foo2'}
-    assert set(r.scan_iter(match="")) == set()
-    assert set(r.scan_iter(match="foo1", _type="string")) == {b'foo1', }
-
-
-def test_scan_iter_multiple_pages(r):
-    all_keys = key_val_dict(size=100)
-    assert all(r.set(k, v) for k, v in all_keys.items())
-    assert set(r.scan_iter()) == set(all_keys)
-
-
-def test_scan_iter_multiple_pages_with_match(r):
-    all_keys = key_val_dict(size=100)
-    assert all(r.set(k, v) for k, v in all_keys.items())
-    # Now add a few keys that don't match the key:<number> pattern.
-    r.set('otherkey', 'foo')
-    r.set('andanother', 'bar')
-    actual = set(r.scan_iter(match='key:*'))
-    assert actual == set(all_keys)
-
-
-def test_scan_multiple_pages_with_count_arg(r):
-    all_keys = key_val_dict(size=100)
-    assert all(r.set(k, v) for k, v in all_keys.items())
-    assert set(r.scan_iter(count=1000)) == set(all_keys)
-
-
-def test_scan_all_in_single_call(r):
-    all_keys = key_val_dict(size=100)
-    assert all(r.set(k, v) for k, v in all_keys.items())
-    # Specify way more than the 100 keys we've added.
-    actual = r.scan(count=1000)
-    assert set(actual[1]) == set(all_keys)
-    assert actual[0] == 0
-
-
-@pytest.mark.slow
-def test_scan_expired_key(r):
-    r.set('expiringkey', 'value')
-    r.pexpire('expiringkey', 1)
-    sleep(1)
-    assert r.scan()[1] == []
-
-
-def test_basic_sort(r):
+def test_basic_sort(r: redis.Redis):
     r.rpush('foo', '2')
     r.rpush('foo', '1')
     r.rpush('foo', '3')
@@ -725,7 +637,7 @@ def test_basic_sort(r):
     assert raw_command(r, 'sort', 'foo', 'asc') == [b'1', b'2', b'3']
 
 
-def test_key_patterns(r):
+def test_key_patterns(r: redis.Redis):
     r.mset({'one': 1, 'two': 2, 'three': 3, 'four': 4})
     assert sorted(r.keys('*o*')) == [b'four', b'one', b'two']
     assert r.keys('t??') == [b'two']
